@@ -10,12 +10,11 @@ from dare.core.dare_manager import DareManager
 
 
 def main(conffile=None):
-
+    darelogger.debug("Using python installtion at '%s' " % sys.prefix)
     if (len(sys.argv) > 1):
         conffile = sys.argv[1]
     else:
-        raise "missing dare configurtion file"
-    darelogger.debug("using python installtion at '%s' " % sys.prefix)
+        raise RuntimeError("missing dare configurtion file")
     darelogger.debug("starting DARE")
     DareManager(conffile)
     darelogger.debug("DARE Exec Done")
